==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.makeproject/src/org/netbeans/modules/cnd/makeproject/ui/wizards/NewProjectWizardUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.cnd.makeproject.ui.wizards;

import java.io.File;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import org.netbeans.api.project.Project;
import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
import org.netbeans.modules.cnd.api.remote.RemoteProject;
import org.netbeans.modules.cnd.api.remote.ServerList;
import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
import org.netbeans.modules.cnd.utils.CndUtils;
import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.remote.spi.FileSystemProvider;
import org.openide.WizardDescriptor;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileSystem;

/**
 * Misc utility functions used when creating new project
 * @author Vladimir Kvashin
 */
public class NewProjectWizardUtils {

    public static boolean isFullRemote(WizardDescriptor wizardDescriptor) {
        return wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV) != null;
    }

    public static FileSystem getFileSystem(WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            String hostUID = (String) wizardDescriptor.getProperty(WizardConstants.PROPERTY_HOST_UID);
            CndUtils.assertNotNull(hostUID, "Null host UID"); //NOI18N
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            return FileSystemProvider.getFileSystem(env);
        } else {
            return FileSystemProvider.getFileSystem(ExecutionEnvironmentFactory.getLocal());
        }
    }

    public static FileObject getFileObject(String path, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            String hostUID = (String) wizardDescriptor.getProperty(WizardConstants.PROPERTY_HOST_UID);
            CndUtils.assertNotNull(hostUID, "Null host UID"); //NOI18N
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            return RemoteFileUtil.getFileObject(path, env);
        } else {
            return CndFileUtils.toFileObject(CndFileUtils.normalizeAbsolutePath(path));
        }
    }

    public static ExecutionEnvironment getExecutionEnvironment(WizardDescriptor wizardDescriptor) {
        String hostUID = (String) wizardDescriptor.getProperty(WizardConstants.PROPERTY_HOST_UID);
        return (hostUID == null) ?
            ServerList.getDefaultRecord().getExecutionEnvironment() :
            ExecutionEnvironmentFactory.fromUniqueID(hostUID);
    }

    public static boolean fileExists(String absolutePath, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            return RemoteFileUtil.fileExists(absolutePath, getExecutionEnvironment(wizardDescriptor));
        } else {
            return new File(absolutePath).exists();
        }
    }

    public static boolean isDirectory(String absolutePath, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            return RemoteFileUtil.isDirectory(absolutePath, getExecutionEnvironment(wizardDescriptor));
        } else {
            return new File(absolutePath).isDirectory();
        }
    }

    public static JFileChooser createFileChooser(Project project,
            String titleText, String buttonText,
            int mode, FileFilter[] filters,
            String initialPath, boolean useParent) {
        
        ExecutionEnvironment execEnv = ExecutionEnvironmentFactory.getLocal();
        if (project != null) {
            RemoteProject remoteProject = project.getLookup().lookup(RemoteProject.class);
            if (remoteProject != null) {
                execEnv = remoteProject.getSourceFileSystemHost();
            }
        }
        return RemoteFileUtil.createFileChooser(execEnv, titleText, buttonText, mode, filters, initialPath, useParent);
    }
    
    public static ExecutionEnvironment getDefaultSourceEnvironment() {
        String externalForm = System.getProperty("cnd.default.project.source.env"); //NOI18N
        if (externalForm != null) {
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(externalForm);
            if (env != null) {
                return env;
            }
        }
        return ExecutionEnvironmentFactory.getLocal();
    }

    public static JFileChooser createFileChooser(WizardDescriptor wd, String titleText,
            String buttonText, int mode, FileFilter[] filters,
            String initialPath, boolean useParent) {

        ExecutionEnvironment execEnv = ExecutionEnvironmentFactory.getLocal();
        if (isFullRemote(wd)) {
            String hostUID = (String) wd.getProperty(WizardConstants.PROPERTY_HOST_UID);
            if (hostUID != null) {
                execEnv = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            }
        }
        return RemoteFileUtil.createFileChooser(execEnv, titleText, buttonText, mode, filters, initialPath, useParent);
    }


}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/cnd.makeproject/src/org/netbeans/modules/cnd/makeproject/ui/wizards/NewProjectWizardUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.cnd.makeproject.ui.wizards;

import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
import java.io.File;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import org.netbeans.api.project.Project;
import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
import org.netbeans.modules.cnd.api.remote.RemoteProject;
import org.netbeans.modules.cnd.api.remote.ServerList;
import org.netbeans.modules.cnd.utils.CndUtils;
import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.remote.spi.FileSystemProvider;
import org.openide.WizardDescriptor;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileSystem;

/**
 * Misc utility functions used when creating new project
 * @author Vladimir Kvashin
 */
public class NewProjectWizardUtils {

    public static boolean isFullRemote(WizardDescriptor wizardDescriptor) {
        return WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor) != null;
    }

    public static FileSystem getFileSystem(WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wizardDescriptor);
            CndUtils.assertNotNull(hostUID, "Null host UID"); //NOI18N
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            return FileSystemProvider.getFileSystem(env);
        } else {
            return FileSystemProvider.getFileSystem(ExecutionEnvironmentFactory.getLocal());
        }
    }

    public static FileObject getFileObject(String path, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wizardDescriptor);
            CndUtils.assertNotNull(hostUID, "Null host UID"); //NOI18N
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            return RemoteFileUtil.getFileObject(path, env);
        } else {
            return CndFileUtils.toFileObject(CndFileUtils.normalizeAbsolutePath(path));
        }
    }

    public static ExecutionEnvironment getExecutionEnvironment(WizardDescriptor wizardDescriptor) {
        String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wizardDescriptor);
        return (hostUID == null) ?
            ServerList.getDefaultRecord().getExecutionEnvironment() :
            ExecutionEnvironmentFactory.fromUniqueID(hostUID);
    }

    public static boolean fileExists(String absolutePath, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            return RemoteFileUtil.fileExists(absolutePath, getExecutionEnvironment(wizardDescriptor));
        } else {
            return new File(absolutePath).exists();
        }
    }

    public static boolean isDirectory(String absolutePath, WizardDescriptor wizardDescriptor) {
        if (isFullRemote(wizardDescriptor)) {
            return RemoteFileUtil.isDirectory(absolutePath, getExecutionEnvironment(wizardDescriptor));
        } else {
            return new File(absolutePath).isDirectory();
        }
    }

    public static JFileChooser createFileChooser(Project project,
            String titleText, String buttonText,
            int mode, FileFilter[] filters,
            String initialPath, boolean useParent) {
        
        ExecutionEnvironment execEnv = ExecutionEnvironmentFactory.getLocal();
        if (project != null) {
            RemoteProject remoteProject = project.getLookup().lookup(RemoteProject.class);
            if (remoteProject != null) {
                execEnv = remoteProject.getSourceFileSystemHost();
            }
        }
        return RemoteFileUtil.createFileChooser(execEnv, titleText, buttonText, mode, filters, initialPath, useParent);
    }
    
    public static ExecutionEnvironment getDefaultSourceEnvironment() {
        String externalForm = System.getProperty("cnd.default.project.source.env"); //NOI18N
        if (externalForm != null) {
            ExecutionEnvironment env = ExecutionEnvironmentFactory.fromUniqueID(externalForm);
            if (env != null) {
                return env;
            }
        }
        return ExecutionEnvironmentFactory.getLocal();
    }

    public static JFileChooser createFileChooser(WizardDescriptor wd, String titleText,
            String buttonText, int mode, FileFilter[] filters,
            String initialPath, boolean useParent) {

        ExecutionEnvironment execEnv = ExecutionEnvironmentFactory.getLocal();
        if (isFullRemote(wd)) {
            String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wd);
            if (hostUID != null) {
                execEnv = ExecutionEnvironmentFactory.fromUniqueID(hostUID);
            }
        }
        return RemoteFileUtil.createFileChooser(execEnv, titleText, buttonText, mode, filters, initialPath, useParent);
    }


}
